@@ -25,34 +25,52 @@ deploy, and monitor any LLMs with ease.
 """
 from __future__ import annotations
 
-import logging as _
+import logging
+import os
 import typing as t
+import warnings
 
 from . import utils as utils
 from .__about__ import __version__ as __version__
 from .exceptions import MissingDependencyError
 
+
 if utils.DEBUG:
-    from bentoml._internal.configuration import set_debug_mode, set_quiet_mode
+    utils.set_debug_mode(True)
+    utils.set_quiet_mode(False)
 
-    set_debug_mode(True)
-    set_quiet_mode(False)
-
-    from bentoml._internal.log import configure_logging
-
-    configure_logging()
-    _.basicConfig(level=_.NOTSET)
+    utils.configure_logging()
+    logging.basicConfig(level=logging.NOTSET)
+else:
+    # configuration for bitsandbytes before import
+    os.environ["BITSANDBYTES_NOWELCOME"] = os.environ.get("BITSANDBYTES_NOWELCOME", "1")
+    # The following warnings from bitsandbytes, and probably not that important
+    # for users to see when DEBUG is False
+    warnings.filterwarnings(
+        "ignore", message="MatMul8bitLt: inputs will be cast from torch.float32 to float16 during quantization"
+    )
+    warnings.filterwarnings(
+        "ignore", message="MatMul8bitLt: inputs will be cast from torch.bfloat16 to float16 during quantization"
+    )
+    warnings.filterwarnings(
+        "ignore",
+        message=(
+            "The installed version of bitsandbytes was compiled without GPU support. 8-bit optimizers and GPU quantization"
+            " are unavailable."
+        ),
+    )
 
 
 _import_structure = {
-    "_llm": ["LLM", "Runner"],
+    "_llm": ["LLM", "Runner", "LLMRunner"],
     "_configuration": ["LLMConfig"],
     "_package": ["build"],
     "exceptions": [],
-    "_schema": ["GenerationInput", "GenerationOutput"],
+    "_schema": ["GenerationInput", "GenerationOutput", "MetadataOutput"],
     "utils": [],
     "models": [],
     "client": [],
+    "playground": [],
     "cli": ["start", "start_grpc"],
     # NOTE: models
     "models.auto": [
@@ -68,6 +86,7 @@ _import_structure = {
     "models.chatglm": ["ChatGLMConfig"],
     "models.starcoder": ["StarCoderConfig"],
     "models.stablelm": ["StableLMConfig"],
+    "models.opt": ["OPTConfig"],
 }
 
 # NOTE: torch and cpm_kernels
@@ -108,6 +127,7 @@ else:
     _import_structure["models.dolly_v2"].extend(["DollyV2"])
     _import_structure["models.starcoder"].extend(["StarCoder"])
     _import_structure["models.stablelm"].extend(["StableLM"])
+    _import_structure["models.opt"].extend(["OPT"])
     _import_structure["models.auto"].extend(["AutoLLM", "MODEL_MAPPING"])
 
 try:
@@ -121,6 +141,7 @@ except MissingDependencyError:
     ]
 else:
     _import_structure["models.flan_t5"].extend(["FlaxFlanT5"])
+    _import_structure["models.opt"].extend(["FlaxOPT"])
     _import_structure["models.auto"].extend(["AutoFlaxLLM", "MODEL_FLAX_MAPPING"])
 
 try:
@@ -132,6 +153,7 @@ except MissingDependencyError:
     _import_structure["utils.dummy_tf_objects"] = [name for name in dir(dummy_tf_objects) if not name.startswith("_")]
 else:
     _import_structure["models.flan_t5"].extend(["TFFlanT5"])
+    _import_structure["models.opt"].extend(["TFOPT"])
     _import_structure["models.auto"].extend(["AutoTFLLM", "MODEL_TF_MAPPING"])
 
 
@@ -141,14 +163,17 @@ if t.TYPE_CHECKING:
     from . import client as client
     from . import exceptions as exceptions
     from . import models as models
+    from . import playground as playground
 
     # Specific types import
     from ._configuration import LLMConfig as LLMConfig
     from ._llm import LLM as LLM
+    from ._llm import LLMRunner as LLMRunner
     from ._llm import Runner as Runner
     from ._package import build as build
     from ._schema import GenerationInput as GenerationInput
     from ._schema import GenerationOutput as GenerationOutput
+    from ._schema import MetadataOutput as MetadataOutput
     from .cli import start as start
     from .cli import start_grpc as start_grpc
     from .models.auto import CONFIG_MAPPING as CONFIG_MAPPING
@@ -160,6 +185,7 @@ if t.TYPE_CHECKING:
     from .models.dolly_v2 import DollyV2Config as DollyV2Config
     from .models.falcon import FalconConfig as FalconConfig
     from .models.flan_t5 import FlanT5Config as FlanT5Config
+    from .models.opt import OPTConfig as OPTConfig
     from .models.stablelm import StableLMConfig as StableLMConfig
     from .models.starcoder import StarCoderConfig as StarCoderConfig
 
@@ -191,6 +217,7 @@ if t.TYPE_CHECKING:
         from .models.auto import AutoLLM as AutoLLM
         from .models.dolly_v2 import DollyV2 as DollyV2
         from .models.flan_t5 import FlanT5 as FlanT5
+        from .models.opt import OPT as OPT
         from .models.stablelm import StableLM as StableLM
         from .models.starcoder import StarCoder as StarCoder
 
@@ -203,6 +230,7 @@ if t.TYPE_CHECKING:
         from .models.auto import MODEL_FLAX_MAPPING as MODEL_FLAX_MAPPING
         from .models.auto import AutoFlaxLLM as AutoFlaxLLM
         from .models.flan_t5 import FlaxFlanT5 as FlaxFlanT5
+        from .models.opt import FlaxOPT as FlaxOPT
 
     try:
         if not utils.is_tf_available():
@@ -213,6 +241,7 @@ if t.TYPE_CHECKING:
         from .models.auto import MODEL_TF_MAPPING as MODEL_TF_MAPPING
         from .models.auto import AutoTFLLM as AutoTFLLM
         from .models.flan_t5 import TFFlanT5 as TFFlanT5
+        from .models.opt import TFOPT as TFOPT
 
 else:
     import sys
@@ -222,5 +251,11 @@ else:
         globals()["__file__"],
         _import_structure,
         module_spec=__spec__,
-        extra_objects={"__version__": __version__},
+        extra_objects={
+            "__version__": __version__,
+            # The below is a special mapping that allows openllm to be used as a dictionary.
+            # This is purely for convenience sake, and should not be used in performance critcal
+            # code. This is also not considered as a public API.
+            "__openllm_special__": {"flax": "AutoFlaxLLM", "tf": "AutoTFLLM", "pt": "AutoLLM"},
+        },
     )
