@@ -24,6 +24,7 @@ import inflection
 
 import openllm
 
+
 if t.TYPE_CHECKING:
     DictStrAny = dict[str, t.Any]
 else:
@@ -55,7 +56,7 @@ class GenerationInput:
     def for_model(cls, model_name: str, **attrs: t.Any) -> type[GenerationInput]:
         llm_config = openllm.AutoConfig.for_model(model_name, **attrs)
         return attr.make_class(
-            inflection.camelize(llm_config.__openllm_model_name__) + "GenerationInput",
+            inflection.camelize(llm_config["model_name"]) + "GenerationInput",
             attrs={
                 "prompt": attr.field(type=str),
                 "llm_config": attr.field(
@@ -77,3 +78,12 @@ class GenerationOutput:
 
     configuration: t.Dict[str, t.Any]
     """A mapping of configuration values for given system."""
+
+
+@attr.frozen(slots=True)
+class MetadataOutput:
+    model_id: str
+    timeout: int
+    model_name: str
+    framework: str
+    configuration: str
