@@ -22,9 +22,19 @@ import inflection
 
 import openllm
 
+
 if t.TYPE_CHECKING:
-    ConfigOrderedDict = OrderedDict[str, openllm.LLMConfig]
+    from collections import _odict_items
+    from collections import _odict_keys
+    from collections import _odict_values
+
+    ConfigOrderedDict = OrderedDict[str, type[openllm.LLMConfig]]
+
+    ConfigKeysView = _odict_keys[str, type[openllm.LLMConfig]]
+    ConfigValuesView = _odict_values[str, type[openllm.LLMConfig]]
+    ConfigItemsView = _odict_items[str, type[openllm.LLMConfig]]
 else:
+    ConfigKeysView = ConfigValuesView = ConfigItemsView = t.Any
     ConfigOrderedDict = OrderedDict
 
 # NOTE: This is the entrypoint when adding new model config
@@ -36,6 +46,7 @@ CONFIG_MAPPING_NAMES = OrderedDict(
         ("starcoder", "StarCoderConfig"),
         ("falcon", "FalconConfig"),
         ("stablelm", "StableLMConfig"),
+        ("opt", "OPTConfig"),
     ]
 )
 
@@ -54,7 +65,7 @@ class _LazyConfigMapping(ConfigOrderedDict):
         value = self._mapping[key]
         module_name = inflection.underscore(key)
         if module_name not in self._modules:
-            self._modules[module_name] = openllm.utils.ModelEnv(module_name).module
+            self._modules[module_name] = openllm.utils.EnvVarMixin(module_name).module
         if hasattr(self._modules[module_name], value):
             return getattr(self._modules[module_name], value)
 
@@ -63,13 +74,15 @@ class _LazyConfigMapping(ConfigOrderedDict):
         return getattr(openllm, value)
 
     def keys(self):
-        return list(self._mapping.keys()) + list(self._extra_content.keys())
+        return t.cast(ConfigKeysView, list(self._mapping.keys()) + list(self._extra_content.keys()))
 
     def values(self):
-        return [self[k] for k in self._mapping.keys()] + list(self._extra_content.values())
+        return t.cast(ConfigValuesView, [self[k] for k in self._mapping.keys()] + list(self._extra_content.values()))
 
     def items(self):
-        return [(k, self[k]) for k in self._mapping.keys()] + list(self._extra_content.items())
+        return t.cast(
+            ConfigItemsView, [(k, self[k]) for k in self._mapping.keys()] + list(self._extra_content.items())
+        )
 
     def __iter__(self):
         return iter(list(self._mapping.keys()) + list(self._extra_content.keys()))
@@ -86,8 +99,15 @@ class _LazyConfigMapping(ConfigOrderedDict):
         self._extra_content[key] = value
 
 
-CONFIG_MAPPING = _LazyConfigMapping(CONFIG_MAPPING_NAMES)
-CONFIG_NAME_ALIASES: dict[str, str] = {"chat_glm": "chatglm", "stable_lm": "stablelm", "star_coder": "starcoder"}
+CONFIG_MAPPING: dict[str, type[openllm.LLMConfig]] = _LazyConfigMapping(CONFIG_MAPPING_NAMES)
+
+# The below handle special alias when we call underscore to the name directly
+# without processing camelcase first.
+CONFIG_NAME_ALIASES: dict[str, str] = {
+    "chat_glm": "chatglm",
+    "stable_lm": "stablelm",
+    "star_coder": "starcoder",
+}
 
 
 class AutoConfig:
