@@ -14,10 +14,17 @@
 
 from __future__ import annotations
 
+import typing as t
 from collections import OrderedDict
 
 from .configuration_auto import CONFIG_MAPPING_NAMES
-from .factory import _BaseAutoLLMClass, _LazyAutoMapping
+from .factory import _BaseAutoLLMClass
+from .factory import _LazyAutoMapping
+
+
+if t.TYPE_CHECKING:
+    import openllm
+    import transformers
 
 MODEL_MAPPING_NAMES = OrderedDict(
     [
@@ -27,10 +34,13 @@ MODEL_MAPPING_NAMES = OrderedDict(
         ("starcoder", "StarCoder"),
         ("falcon", "Falcon"),
         ("stablelm", "StableLM"),
+        ("opt", "OPT"),
     ]
 )
 
-MODEL_MAPPING = _LazyAutoMapping(CONFIG_MAPPING_NAMES, MODEL_MAPPING_NAMES)
+MODEL_MAPPING: dict[
+    type[openllm.LLMConfig], type[openllm.LLM[transformers.PreTrainedModel, transformers.PreTrainedTokenizerFast]]
+] = _LazyAutoMapping(CONFIG_MAPPING_NAMES, MODEL_MAPPING_NAMES)
 
 
 class AutoLLM(_BaseAutoLLMClass):
