@@ -14,14 +14,28 @@
 
 from __future__ import annotations
 
+import typing as t
 from collections import OrderedDict
 
 from .configuration_auto import CONFIG_MAPPING_NAMES
-from .factory import _BaseAutoLLMClass, _LazyAutoMapping
+from .factory import _BaseAutoLLMClass
+from .factory import _LazyAutoMapping
 
-MODEL_FLAX_MAPPING_NAMES = OrderedDict([("flan_t5", "FlaxFlanT5")])
 
-MODEL_FLAX_MAPPING = _LazyAutoMapping(CONFIG_MAPPING_NAMES, MODEL_FLAX_MAPPING_NAMES)
+if t.TYPE_CHECKING:
+    import openllm
+    import transformers
+
+MODEL_FLAX_MAPPING_NAMES = OrderedDict(
+    [
+        ("flan_t5", "FlaxFlanT5"),
+        ("opt", "FlaxOPT"),
+    ]
+)
+
+MODEL_FLAX_MAPPING: dict[
+    type[openllm.LLMConfig], type[openllm.LLM[transformers.FlaxPreTrainedModel, transformers.PreTrainedTokenizerFast]]
+] = _LazyAutoMapping(CONFIG_MAPPING_NAMES, MODEL_FLAX_MAPPING_NAMES)
 
 
 class AutoFlaxLLM(_BaseAutoLLMClass):
