@@ -28,7 +28,8 @@ class FalconConfig(openllm.LLMConfig):
         "name_type": "lowercase",
         "trust_remote_code": True,
         "requires_gpu": True,
-        "timeout": 3600000,
+        "timeout": int(36e6),
+        "use_pipeline": True,
         "url": "https://falconllm.tii.ae/",
         "requirements": ["einops", "xformers", "safetensors"],
         "default_id": "tiiuae/falcon-7b",
