@@ -24,14 +24,17 @@ import os
 import typing as t
 
 import attr
+
 from bentoml._internal.utils import analytics as _internal_analytics
 from bentoml._internal.utils.analytics import usage_stats as _internal_usage
 
+
 if t.TYPE_CHECKING:
     import openllm
 
 from ..__about__ import __version__
 
+
 ENV_VARS_TRUE_VALUES = {"1", "ON", "YES", "TRUE"}
 
 # This variable is a proxy that will control BENTOML_DO_NOT_TRACK
@@ -81,7 +84,7 @@ class StartInitEvent(_internal_analytics.schemas.EventMeta):
 
     @staticmethod
     def handler(llm_config: openllm.LLMConfig) -> StartInitEvent:
-        return StartInitEvent(model_name=llm_config.__openllm_model_name__, llm_config=llm_config.model_dump())
+        return StartInitEvent(model_name=llm_config["model_name"], llm_config=llm_config.model_dump())
 
 
 def track_start_init(
