@@ -16,7 +16,8 @@ from __future__ import annotations
 
 import typing as t
 
-from ..utils import DummyMetaclass, require_backends
+from ..utils import DummyMetaclass
+from ..utils import require_backends
 
 
 class FlaxFlanT5(metaclass=DummyMetaclass):
@@ -26,6 +27,13 @@ class FlaxFlanT5(metaclass=DummyMetaclass):
         require_backends(self, ["flax"])
 
 
+class FlaxOPT(metaclass=DummyMetaclass):
+    _backends = ["flax"]
+
+    def __init__(self, *args: t.Any, **attrs: t.Any):
+        require_backends(self, ["flax"])
+
+
 class AutoFlaxLLM(metaclass=DummyMetaclass):
     _backends = ["flax"]
 
