@@ -16,7 +16,8 @@ from __future__ import annotations
 
 import typing as t
 
-from ..utils import DummyMetaclass, require_backends
+from ..utils import DummyMetaclass
+from ..utils import require_backends
 
 
 class TFFlanT5(metaclass=DummyMetaclass):
@@ -26,6 +27,13 @@ class TFFlanT5(metaclass=DummyMetaclass):
         require_backends(self, ["tf"])
 
 
+class TFOPT(metaclass=DummyMetaclass):
+    _backends = ["tf"]
+
+    def __init__(self, *args: t.Any, **attrs: t.Any):
+        require_backends(self, ["tf"])
+
+
 class AutoTFLLM(metaclass=DummyMetaclass):
     _backends = ["tf"]
 
