@@ -13,12 +13,14 @@
 # limitations under the License.
 from __future__ import annotations
 
-import dataclasses
 import typing as t
 
+import attr
+
 import openllm
 from openllm._prompt import PromptFormatter
 
+
 if t.TYPE_CHECKING:
     DictStrStr = dict[str, str]
 else:
@@ -34,13 +36,11 @@ class PartialDict(DictStrStr):
         return "{" + key + "}"
 
 
-@dataclasses.dataclass(slots=True)
+@attr.define(slots=True)
 class PromptTemplate:
     template: str
     input_variables: t.Sequence[str]
 
-    model_config = {"extra": "forbid"}
-
     def to_str(self, __partial_dict__: PartialDict | None = None, **attrs: str) -> str:
         """Generate a prompt from the template and input variables"""
         if __partial_dict__:
@@ -58,7 +58,7 @@ class PromptTemplate:
 
     @classmethod
     def from_default(cls, model: str) -> PromptTemplate:
-        template = getattr(openllm.utils.ModelEnv(model).module, "DEFAULT_PROMPT_TEMPLATE")
+        template = getattr(openllm.utils.EnvVarMixin(model).module, "DEFAULT_PROMPT_TEMPLATE")
         if template is None:
             raise ValueError(f"Model {model} does not have a default prompt template.")
         return cls.from_template(template)
